@@ -15,15 +15,18 @@
 #    under the License.
 
 from django.utils.translation import ugettext_lazy as _
+from django.conf import settings  # noqa
 
 import horizon
 
+service_type = getattr(settings, 'MONITORING_SERVICE_TYPE', 'monitoring')
 
 class Monitoring(horizon.Dashboard):
     name = _("Monitoring")
     slug = "monitoring"
     panels = ('overview', 'alarmdefs', 'alarms', 'notifications',)
     default_panel = 'overview'
-
+    policy_rules = (("monitoring", "monitoring:monitoring"),)
+    permissions = (('openstack.services.' + service_type),)
 
 horizon.register(Monitoring)
